﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using PCBI.Automation;
using System.IO;

namespace Demo6CSharp
{
    public partial class Form1 : Form
    {

        private string globalOutputDirectory = @"C:\Tests\GerberFiles\";
        private string tempDir = @"C:\Tests\converterTemp\";
        private IPCBIWindow mainWindowPCBI;
        public Form1()
        {
            InitializeComponent();
        }


        private void button1_Click(object sender, EventArgs e)
        {
            IAutomation.IAutomationInit();
            mainWindowPCBI = IAutomation.CreateNewPCBIWindow(true);
            LoadIPC2581Files(mainWindowPCBI);
        }

        private void button2_Click(object sender, EventArgs e)
        {
            //start converter with loaded job
            if(mainWindowPCBI!=null)
                ClassConverter.ConvertODBToGerber("", globalOutputDirectory, mainWindowPCBI);
        }

        public void LoadIPC2581Files(IPCBIWindow window)
        {
            PCBI_IPC2581.IFilterIPC2581 FilterIPC = new PCBI_IPC2581.IFilterIPC2581(window);

            OpenFileDialog openDLG = new OpenFileDialog();
            openDLG.Filter = "IPC2581 files (*.cvg)|*.cvg|All files (*.*)|*.*";
            openDLG.Title = "Select an IPC2581 File to convert it in gerber274x";

            if (openDLG.ShowDialog() != DialogResult.OK)
                return;

            if (!FilterIPC.Load(openDLG.FileName, tempDir, true))
            {
                System.Diagnostics.Debug.WriteLine("Error, check the PCBI error log!");
                return;
            }
        }


        public class ClassConverter
        {
            /// <summary>
            /// Select the outputdirectory and save all layer as gerberfiles.
            /// </summary>
            /// <param name="window">The main PCB-Investigator window.</param>
            public void SaveJobAsGerber(IPCBIWindow window)
            {
                FolderBrowserDialog dirDLG = new FolderBrowserDialog();
                //select the output directory
                dirDLG.Description = "Select directroy for layerfiles as gerber274x.";
                if (dirDLG.ShowDialog() != DialogResult.OK)
                    return;

                //here is possible to select your own directories
                ConvertODBToGerber(window.GetODBJobDirectory(), dirDLG.SelectedPath, window);
            }
            /// <summary>
            /// Converts all layers (without the component layers) to gerber files and save it in one directory.
            /// </summary>
            /// <param name="JobPath">The job who should be loaded.</param>
            /// <param name="GerberDirectory">Output directory for the new files.</param>
            /// <param name="window">PCB-Investigator to convert the files.</param>
            public static void ConvertODBToGerber(string JobPath, string GerberDirectory, IPCBIWindow window)
            {
                //check is a job loaded, if not load an job!
                if (!window.JobIsLoaded && !window.LoadODBJob(JobPath))
                    return;

                IStep stepCurrent = window.GetCurrentStep();

                if (stepCurrent == null) return;
                if (!Directory.Exists(GerberDirectory))
                {
                    Directory.CreateDirectory(GerberDirectory);
                }
                foreach (string layername in stepCurrent.GetAllLayerNames()) //check each layer and save gerber files for it.
                {
                    ILayer layer = stepCurrent.GetLayer(layername);

                    if (layer is IODBLayer)
                    {
                        ((IODBLayer)layer).SaveLayerAsGerber(GerberDirectory + "\\" + layername + ".ger");
                    }
                }
            }
        }

 
    }
}
